==> openshift-model-operatorhub-6.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterServiceVersionSpecBuilder extends ClusterServiceVersionSpecFluent<ClusterServiceVersionSpecBuilder> implements VisitableBuilder<ClusterServiceVersionSpec,ClusterServiceVersionSpecBuilder>{
  public ClusterServiceVersionSpecBuilder() {
    this(false);
  }
  public ClusterServiceVersionSpecBuilder(Boolean validationEnabled) {
    this(new ClusterServiceVersionSpec(), validationEnabled);
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterServiceVersionSpec(), validationEnabled);
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent,ClusterServiceVersionSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent,ClusterServiceVersionSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterServiceVersionSpec());

    if (instance != null) {
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withApiservicedefinitions(instance.getApiservicedefinitions());
      fluent.withCleanup(instance.getCleanup());
      fluent.withCustomresourcedefinitions(instance.getCustomresourcedefinitions());
      fluent.withDescription(instance.getDescription());
      fluent.withDisplayName(instance.getDisplayName());
      fluent.withIcon(instance.getIcon());
      fluent.withInstall(instance.getInstall());
      fluent.withInstallModes(instance.getInstallModes());
      fluent.withKeywords(instance.getKeywords());
      fluent.withLabels(instance.getLabels());
      fluent.withLinks(instance.getLinks());
      fluent.withMaintainers(instance.getMaintainers());
      fluent.withMaturity(instance.getMaturity());
      fluent.withMinKubeVersion(instance.getMinKubeVersion());
      fluent.withNativeAPIs(instance.getNativeAPIs());
      fluent.withProvider(instance.getProvider());
      fluent.withRelatedImages(instance.getRelatedImages());
      fluent.withReplaces(instance.getReplaces());
      fluent.withSelector(instance.getSelector());
      fluent.withSkips(instance.getSkips());
      fluent.withVersion(instance.getVersion());
      fluent.withWebhookdefinitions(instance.getWebhookdefinitions());
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withApiservicedefinitions(instance.getApiservicedefinitions());
      fluent.withCleanup(instance.getCleanup());
      fluent.withCustomresourcedefinitions(instance.getCustomresourcedefinitions());
      fluent.withDescription(instance.getDescription());
      fluent.withDisplayName(instance.getDisplayName());
      fluent.withIcon(instance.getIcon());
      fluent.withInstall(instance.getInstall());
      fluent.withInstallModes(instance.getInstallModes());
      fluent.withKeywords(instance.getKeywords());
      fluent.withLabels(instance.getLabels());
      fluent.withLinks(instance.getLinks());
      fluent.withMaintainers(instance.getMaintainers());
      fluent.withMaturity(instance.getMaturity());
      fluent.withMinKubeVersion(instance.getMinKubeVersion());
      fluent.withNativeAPIs(instance.getNativeAPIs());
      fluent.withProvider(instance.getProvider());
      fluent.withRelatedImages(instance.getRelatedImages());
      fluent.withReplaces(instance.getReplaces());
      fluent.withSelector(instance.getSelector());
      fluent.withSkips(instance.getSkips());
      fluent.withVersion(instance.getVersion());
      fluent.withWebhookdefinitions(instance.getWebhookdefinitions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpec instance) {
    this(instance,false);
  }
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterServiceVersionSpec());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withApiservicedefinitions(instance.getApiservicedefinitions());
      this.withCleanup(instance.getCleanup());
      this.withCustomresourcedefinitions(instance.getCustomresourcedefinitions());
      this.withDescription(instance.getDescription());
      this.withDisplayName(instance.getDisplayName());
      this.withIcon(instance.getIcon());
      this.withInstall(instance.getInstall());
      this.withInstallModes(instance.getInstallModes());
      this.withKeywords(instance.getKeywords());
      this.withLabels(instance.getLabels());
      this.withLinks(instance.getLinks());
      this.withMaintainers(instance.getMaintainers());
      this.withMaturity(instance.getMaturity());
      this.withMinKubeVersion(instance.getMinKubeVersion());
      this.withNativeAPIs(instance.getNativeAPIs());
      this.withProvider(instance.getProvider());
      this.withRelatedImages(instance.getRelatedImages());
      this.withReplaces(instance.getReplaces());
      this.withSelector(instance.getSelector());
      this.withSkips(instance.getSkips());
      this.withVersion(instance.getVersion());
      this.withWebhookdefinitions(instance.getWebhookdefinitions());
      this.withAnnotations(instance.getAnnotations());
      this.withApiservicedefinitions(instance.getApiservicedefinitions());
      this.withCleanup(instance.getCleanup());
      this.withCustomresourcedefinitions(instance.getCustomresourcedefinitions());
      this.withDescription(instance.getDescription());
      this.withDisplayName(instance.getDisplayName());
      this.withIcon(instance.getIcon());
      this.withInstall(instance.getInstall());
      this.withInstallModes(instance.getInstallModes());
      this.withKeywords(instance.getKeywords());
      this.withLabels(instance.getLabels());
      this.withLinks(instance.getLinks());
      this.withMaintainers(instance.getMaintainers());
      this.withMaturity(instance.getMaturity());
      this.withMinKubeVersion(instance.getMinKubeVersion());
      this.withNativeAPIs(instance.getNativeAPIs());
      this.withProvider(instance.getProvider());
      this.withRelatedImages(instance.getRelatedImages());
      this.withReplaces(instance.getReplaces());
      this.withSelector(instance.getSelector());
      this.withSkips(instance.getSkips());
      this.withVersion(instance.getVersion());
      this.withWebhookdefinitions(instance.getWebhookdefinitions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterServiceVersionSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterServiceVersionSpec build() {
    ClusterServiceVersionSpec buildable = new ClusterServiceVersionSpec(fluent.getAnnotations(),fluent.buildApiservicedefinitions(),fluent.buildCleanup(),fluent.buildCustomresourcedefinitions(),fluent.getDescription(),fluent.getDisplayName(),fluent.buildIcon(),fluent.buildInstall(),fluent.buildInstallModes(),fluent.getKeywords(),fluent.getLabels(),fluent.buildLinks(),fluent.buildMaintainers(),fluent.getMaturity(),fluent.getMinKubeVersion(),fluent.getNativeAPIs(),fluent.buildProvider(),fluent.buildRelatedImages(),fluent.getReplaces(),fluent.buildSelector(),fluent.getSkips(),fluent.getVersion(),fluent.buildWebhookdefinitions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operatorhub-6.13.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ClusterServiceVersionSpecBuilder extends ClusterServiceVersionSpecFluent<ClusterServiceVersionSpecBuilder> implements VisitableBuilder<ClusterServiceVersionSpec,ClusterServiceVersionSpecBuilder>{
  public ClusterServiceVersionSpecBuilder() {
    this(new ClusterServiceVersionSpec());
  }
  
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent) {
    this(fluent, new ClusterServiceVersionSpec());
  }
  
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpecFluent<?> fluent,ClusterServiceVersionSpec instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ClusterServiceVersionSpecBuilder(ClusterServiceVersionSpec instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ClusterServiceVersionSpecFluent<?> fluent;
  
  public ClusterServiceVersionSpec build() {
    ClusterServiceVersionSpec buildable = new ClusterServiceVersionSpec(fluent.getAnnotations(),fluent.buildApiservicedefinitions(),fluent.buildCleanup(),fluent.buildCustomresourcedefinitions(),fluent.getDescription(),fluent.getDisplayName(),fluent.buildIcon(),fluent.buildInstall(),fluent.buildInstallModes(),fluent.getKeywords(),fluent.getLabels(),fluent.buildLinks(),fluent.buildMaintainers(),fluent.getMaturity(),fluent.getMinKubeVersion(),fluent.getNativeAPIs(),fluent.buildProvider(),fluent.buildRelatedImages(),fluent.getReplaces(),fluent.buildSelector(),fluent.getSkips(),fluent.getVersion(),fluent.buildWebhookdefinitions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
